pub fn read_file_content(path: &Path) -> Option<(String, ContentType)>Expand description
Read any file and convert to text content Uses pdftotext for PDFs (fast and accurate)
pub fn read_file_content(path: &Path) -> Option<(String, ContentType)>Read any file and convert to text content Uses pdftotext for PDFs (fast and accurate)